@@ -294,8 +294,8 @@ class TestArgcomplete(unittest.TestCase):
         for cmd, output in expected_outputs:
             self.assertEqual(set(self.run_completer(make_parser(), cmd)), set(output))
         zsh_expected_outputs = (
-            ("prog --url ", ["http://url1:foo", "http://url2:bar"]),
-            ('prog --url "', ["http://url1:foo", "http://url2:bar"]),
+            ("prog --url ", ["http\\://url1:foo", "http\\://url2:bar"]),
+            ('prog --url "', ["http\\://url1:foo", "http\\://url2:bar"]),
             ('prog --url "http://url1" --email ', ["a@b.c:", "a@b.d:", "ab@c.d:", "bcd@e.f:", "bce@f.g:"]),
             ('prog --url "http://url1" --email a', ["a@b.c:", "a@b.d:", "ab@c.d:"]),
             ('prog --url "http://url1" --email "a@', ["a@b.c:", "a@b.d:"]),
@@ -1300,7 +1300,8 @@ class TestBash(TestBashZshBase, unittest.TestCase):
 
 
 class TestZsh(TestBashZshBase, unittest.TestCase):
-    expected_failures = [
+    skipped = [
+        "test_parse_special_characters",
         "test_parse_special_characters_dollar",
         "test_comp_point",  # FIXME
         "test_completion_environment",  # FIXME
@@ -1308,9 +1309,6 @@ class TestZsh(TestBashZshBase, unittest.TestCase):
         "test_wordbreak_chars",  # FIXME
     ]
 
-    def test_parse_special_characters(self):
-        pass  # FIXME: test crashes in teardown
-
     def repl_provider(self):
         return zsh_repl()
 
@@ -1370,25 +1368,21 @@ class TestBashGlobal(TestBash):
             self.assertEqual(self.sh.run_command(command), "arg\r\n")
 
     @unittest.skipIf(os.uname()[0] == "Darwin", "Skip test that fails on MacOS")
-    @unittest.skipIf(sys.version_info < (3, 8), "Skip test that fails on Python 3.7 with importlib_metadata > 4")
     def test_console_script_module(self):
         """Test completing a console_script for a module."""
         self._test_console_script()
 
     @unittest.skipIf(os.uname()[0] == "Darwin", "Skip test that fails on MacOS")
-    @unittest.skipIf(sys.version_info < (3, 8), "Skip test that fails on Python 3.7 with importlib_metadata > 4")
     def test_console_script_package(self):
         """Test completing a console_script for a package."""
         self._test_console_script(package=True)
 
     @unittest.skipIf(os.uname()[0] == "Darwin", "Skip test that fails on MacOS")
-    @unittest.skipIf(sys.version_info < (3, 8), "Skip test that fails on Python 3.7 with importlib_metadata > 4")
     def test_console_script_module_wheel(self):
         """Test completing a console_script for a module from a wheel."""
         self._test_console_script(wheel=True)
 
     @unittest.skipIf(os.uname()[0] == "Darwin", "Skip test that fails on MacOS")
-    @unittest.skipIf(sys.version_info < (3, 8), "Skip test that fails on Python 3.7 with importlib_metadata > 4")
     def test_console_script_package_wheel(self):
         """Test completing a console_script for a package from a wheel."""
         self._test_console_script(package=True, wheel=True)
